Codecs for variable-length objects
==================================
.. automodule:: numcodecs.vlen

VLenUTF8
--------
.. autoclass:: VLenUTF8

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config


VLenBytes
---------
.. autoclass:: VLenBytes

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config


VLenArray
---------
.. autoclass:: VLenArray

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config
